@@ -163,11 +163,14 @@ sub generate_codegen_request {
         } elsif ($key eq 'map_package') {
             push @mappings, $mapping = {};
             $mapping->{package} = $value;
+        } elsif ($key eq 'map_message') {
+            push @mappings, $mapping = {};
+            $mapping->{message} = $value;
         } elsif ($key eq 'pb_prefix') {
             push @mappings, $mapping = {};
             $mapping->{pb_prefix} = $value;
-        } elsif ($key eq 'prefix') {
-            $mapping->{prefix} = _perlify_package($value);
+        } elsif ($key eq 'prefix' || $key eq 'to') {
+            $mapping->{$key} = _perlify_package($value);
         } elsif (!_to_option(($mapping ? $mapping->{options} : \%global_options), $key, $value)) {
             return error("Unrecognized option key '$key'");
         }
@@ -221,7 +224,7 @@ Google::ProtocolBuffers::Dynamic::MakeModule
 
 =head1 VERSION
 
-version 0.41_07
+version 0.41_08
 
 =head1 AUTHOR
 
